@@ -147,6 +147,7 @@ sub add {
 sub edit {
 
     &create_links;
+    $form->{$form->{ARAP}} = $form->{"$form->{ARAP}_1"};
     $form->{title} = $locale->text("Edit");
     if ($form->{reverse}){
         if ($form->{ARAP} eq 'AR'){
@@ -339,8 +340,6 @@ sub create_links {
     }
 
     $form->{rowcount}++ if ( $form->{id} || !$form->{rowcount} );
-
-    $form->{ $form->{ARAP} } = $form->{"$form->{ARAP}_1"};
     $form->{rowcount} = 1 unless $form->{"$form->{ARAP}_amount_1"};
 
     $form->{locked} =
@@ -355,6 +354,8 @@ sub create_links {
           if $myconfig{acs} =~ /$form->{ARAP}--Add Transaction/;
     }
     #$form->generate_selects(\%myconfig);
+    $form->{$form->{ARAP}} = $form->{"$form->{ARAP}_1"} unless $form->{$form->{ARAP}};
+
 }
 
 sub form_header {
@@ -767,6 +768,7 @@ qq|<td><input data-dojo-type="dijit/form/TextBox" name="description_$i" size=40
 
     $form->hide_form( "oldinvtotal", "oldtotalpaid", "taxaccounts" );
 
+     $form->{"select$form->{ARAP}"} =~ s/(\Qoption value="$form->{$form->{ARAP}}"\E)/$1 selected="selected"/;
     print qq|
         <tr>
       <th align=left>$form->{invtotal}</th>
@@ -1337,6 +1339,7 @@ sub post {
     ($name) = split /--/, $form->{ $form->{vc} };
     if ( $form->{"old$form->{vc}"} ne qq|$name--$form->{"$form->{vc}_id"}|
          and $form->{"old$form->{vc}"} ne $name) {
+        $form->info('Data changed on Post; form recalculated. Please re-post.');
         &update;
         $form->finalize_request();
     }
