@@ -212,7 +212,7 @@ $$
            AS used,
            SUM(CASE WHEN transtype = 'as' AND i.qty < 0 then -1*i.qty ELSE 0 END)
            AS assembled,
-           SUM(CASE WHEN transtype = 'ia' THEN i.qty ELSE 0 END)
+           SUM(CASE WHEN transtype = 'ia' THEN -1 * i.qty ELSE 0 END)
            AS adjusted
       FROM invoice i
       JOIN parts p ON (i.parts_id = p.id)
@@ -348,6 +348,11 @@ BEGIN
 
 SELECT * INTO inv FROM inventory_report where id = in_id;
 
+IF inv.trans_id IS NOT NULL THEN
+   -- already approved
+   RETURN inv;
+END IF;
+
 INSERT INTO gl (description, transdate, reference, approved, trans_type_code)
         VALUES ('Transaction due to approval of inventory adjustment',
                 inv.transdate, 'invadj-' || in_id, true, 'ia')
