@@ -119,7 +119,9 @@ BEGIN
 END;
 $$;
 
-GRANT ALL ON SCHEMA public TO public;
+GRANT SELECT ON periods TO public; -- 'periods' is a view in Pg-database
+GRANT SELECT ON location_class_to_entity_class TO PUBLIC;
+
 
 \echo BASE ROLES
 SELECT lsmb__create_role('base_user');
@@ -1069,7 +1071,8 @@ SELECT lsmb__grant_menu('sic_create', id, 'allow')
   FROM unnest(array[154,248]) id;
 
 SELECT lsmb__create_role('sic_edit');
-SELECT lsmb__grant_perms('sic_edit', 'sic', 'UPDATE');
+SELECT lsmb__grant_perms('sic_edit', 'sic', ptype)
+  FROM unnest(array['UPDATE'::text, 'DELETE']) ptype;
 SELECT lsmb__grant_menu('sic_edit', 155, 'allow');
 
 SELECT lsmb__create_role('sic_all');
@@ -1150,7 +1153,8 @@ SELECT lsmb__grant_perms('assets_depreciate', 'asset_report_id_seq', 'ALL');
 SELECT lsmb__grant_perms('assets_depreciate', 'asset_report', 'UPDATE');
 SELECT lsmb__grant_perms('assets_depreciate', obj, ptype)
   FROM unnest(array['SELECT'::text, 'INSERT']) ptype,
-       unnest(array['asset_report'::text, 'asset_report_line', 'asset_item',
+       unnest(array['asset_report'::text, 'asset_report_line',
+                    'asset_item', 'asset_rl_to_disposal_method',
                     'asset_class']) obj;
 
 SELECT lsmb__grant_menu('assets_depreciate', 238, 'allow');
